# SupplyNetPy Documentation

SupplyNetPy is a Python library specifically designed and developed to model and simulate different supply chain problems with ease. It provides configurable components such as suppliers, manufacturers, distributors, and demand points for creating arbitrary supply chain networks, along with configurable policies for inventory management and replenishment. With SupplyNetPy, we can quickly assemble a supply chain, specify demand and supply behaviors, and run simulations to evaluate performance metrics like throughput and profit.

## Table of Contents

- [SupplyNetPy in 10 minutes](ten_min.md)
    - [Installation](ten_min.md#installation)
    - [Creating a supply chain network](ten_min.md#create-nodes)
    - [Simulating supply chains](ten_min.md#assemble-and-simulate-the-network)
- [Examples](example.md)
- [API references](api-reference/api-intro.md)
- [About](about.md)
